@@ -172,7 +172,7 @@ class StandardCipherExecutable(CipherExecutable):
     _cipher_object_factory: ClassVar[CipherObjectFactory]
 
     def __new__(mcs, name, bases, nmspc, cipher: Optional[CipherObjectFactory] = None):
-        keywords = dict(abstract=bool(cipher))
+        keywords = dict(abstract=not cipher)
         try:
             keywords.update(blocksize=cipher.block_size)
         except AttributeError:
