@@ -3,7 +3,7 @@
 from base64 import b16decode
 from binascii import Error
 
-from refinery import Unit, arg, drain
+from refinery import Unit, Arg
 from refinery.units.blockwise.xor import xor
 
 
@@ -11,7 +11,7 @@ class n40(Unit):
     """
     Decrypts hex-encoded strings in various latin-american banker families, including N40.
     """
-    def __init__(self, key: arg(help='Decryption key.')):
+    def __init__(self, key: Arg(help='Decryption key.')):
         ...
 
     def process(self, data):
@@ -19,5 +19,5 @@ class n40(Unit):
             data = b16decode(data, casefold=True)
         except Error:
             self.log_warn('Input was not hex-encoded; ignoring this step.')
-        mask = data[1:] | xor(self.args.key) | drain
+        mask = data[1:] | xor(self.args.key) | bytearray
         return bytearray(0xFF + b - a if b <= a else b - a for a, b in zip(data, mask))
