@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from refinery.units import arg, Unit
+from refinery.units import Arg, Unit
 
 
 class repl(Unit):
@@ -10,9 +10,9 @@ class repl(Unit):
 
     def __init__(
         self,
-        search : arg(help='This is the search term.'),
-        replace: arg(help='The substitution string. Leave this empty to remove all occurrences of the search term.') = B'',
-        count  : arg.number('-n', help='Only replace the given number of occurrences') = -1
+        search : Arg(help='This is the search term.'),
+        replace: Arg(help='The substitution string. Leave this empty to remove all occurrences of the search term.') = B'',
+        count  : Arg.Number('-n', help='Only replace the given number of occurrences') = -1
     ):
         super().__init__(search=search, replace=replace, count=count)
 
